# The Dazed Gerbil's Command Line Tools

This is intended to become a simple set of tools I use on a regular basis when developing a cli based app.

You almost certainly don't want to use this. There are probably hundreds of alternatives on PyPi already - each one notably better than my own.
